
# Class: ApplyTrainedModelsContainer


A container with multiple classifiers in it.

URI: [https://w3id.org/neat/ApplyTrainedModelsContainer](https://w3id.org/neat/ApplyTrainedModelsContainer)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[ApplyTrainedModel]<models%200..*-++[ApplyTrainedModelsContainer],[ApplyTrainedModel])](https://yuml.me/diagram/nofunky;dir:TB/class/[ApplyTrainedModel]<models%200..*-++[ApplyTrainedModelsContainer],[ApplyTrainedModel])

## Attributes


### Own

 * [➞models](applyTrainedModelsContainer__models.md)  <sub>0..\*</sub>
     * Description: Models that need to be used for link prediction.
     * Range: [ApplyTrainedModel](ApplyTrainedModel.md)
